@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PodWeaver;
 {
-  $Dist::Zilla::Plugin::PodWeaver::VERSION = '4.001';
+  $Dist::Zilla::Plugin::PodWeaver::VERSION = '4.002';
 }
 # ABSTRACT: weave your Pod together from configuration and Dist::Zilla
 use Moose;
@@ -56,10 +56,22 @@ around dump_config => sub
   my ($orig, $self) = @_;
   my $config = $self->$orig;
 
-  $config->{'' . __PACKAGE__} = {
-     $self->config_plugin ? ( config_plugin => $self->config_plugin ) : (),
-     finder => $self->finder,
+  my $our = {
+    $self->config_plugin ? ( config_plugin => $self->config_plugin ) : (),
+    finder => $self->finder,
   };
+
+  $our->{plugins} = [];
+  for my $plugin (@{ $self->weaver->plugins }) {
+    push @{ $our->{plugins} }, {
+      class   => $plugin->meta->name,
+      name    => $plugin->plugin_name,
+      version => $plugin->VERSION,
+    };
+  }
+
+  $config->{'' . __PACKAGE__} = $our;
+
   return $config;
 };
 
@@ -135,7 +147,7 @@ Dist::Zilla::Plugin::PodWeaver - weave your Pod together from configuration and
 
 =head1 VERSION
 
-version 4.001
+version 4.002
 
 =head1 DESCRIPTION
 
